@@ -152,7 +152,7 @@ do_e(int argc, char **argv)
 		ts.tv_nsec = WAIT_INTERVAL;
 		for (i = 0; i < argc; i++) {
 			ebeginv("Waiting for %s", argv[i]);
-			for (;;){
+			for (;;) {
 				if (exists(argv[i]))
 					break;
 				if (nanosleep(&ts, NULL) == -1)
@@ -298,7 +298,7 @@ do_service(int argc, char **argv)
 			}
 		}
 		ok = rc_service_started_daemon(service, exec, NULL, idx);
-			
+
 	} else if (strcmp(applet, "service_crashed") == 0) {
 		ok = (_rc_can_find_pids() &&
 		    rc_service_daemons_crashed(service) &&
@@ -429,6 +429,17 @@ run_applets(int argc, char **argv)
 	char *p;
 	pid_t pid = 0;
 
+	/* Bug 351712: We need an extra way to explicitly select an applet OTHER
+	 * than trusting argv[0], as argv[0] is not going to be the applet value if
+	 * we are doing SELinux context switching. For this, we allow calls such as
+	 * 'rc --applet APPLET', and shift ALL of argv down by two array items. */
+	if (strcmp(applet, "rc") == 0 && argc >= 3 &&
+		    (strcmp(argv[1],"--applet") == 0 || strcmp(argv[1], "-a") == 0)) {
+		applet = argv[2];
+		argv += 2;
+		argc -= 2;
+	}
+
 	/* These are designed to be applications in their own right */
 	if (strcmp(applet, "fstabinfo") == 0)
 		exit(fstabinfo(argc, argv));
@@ -476,7 +487,7 @@ run_applets(int argc, char **argv)
 				exit(EXIT_FAILURE);
 		}
 		exit(EXIT_SUCCESS);
-	}; 
+	};
 
 	if (applet[0] == 'e' || (applet[0] == 'v' && applet[1] == 'e'))
 		exit(do_e(argc, argv));
