@@ -153,7 +153,7 @@ cleanup(void)
 
 #ifdef DEBUG_MEMORY
 	while (p1) {
-		p2 = LIST_NEXT(p1, entries); 
+		p2 = LIST_NEXT(p1, entries);
 		free(p1);
 		p1 = p2;
 	}
@@ -315,7 +315,7 @@ open_shell(void)
 {
 	const char *shell;
 	struct passwd *pw;
-	
+
 #ifdef __linux__
 	const char *sys = rc_sys();
 
@@ -586,7 +586,7 @@ do_stop_services(const char *newlevel, bool parallel, bool going_down)
 	}
 
 	crashed = rc_conf_yesno("rc_crashed_stop");
-	
+
 	nostop = rc_stringlist_split(rc_conf_value("rc_nostop"), " ");
 	TAILQ_FOREACH_REVERSE(service, stop_services, rc_stringlist, entries)
 	{
@@ -773,14 +773,16 @@ handle_bad_signal(int sig)
 #endif
 
 #include "_usage.h"
-#define getoptstring "o:s:S" getoptstring_COMMON
+#define getoptstring "a:o:s:S" getoptstring_COMMON
 static const struct option longopts[] = {
+	{ "applet",   1, NULL, 'a' },
 	{ "override", 1, NULL, 'o' },
 	{ "service",  1, NULL, 's' },
 	{ "sys",      0, NULL, 'S' },
 	longopts_COMMON
 };
 static const char * const longopts_help[] = {
+	"runs the applet specified by the next argument",
 	"override the next runlevel to change into\n"
 	"when leaving single user or boot runlevels",
 	"runs the service specified with the rest\nof the arguments",
@@ -804,6 +806,7 @@ main(int argc, char **argv)
 	int opt;
 	bool parallel;
 	int regen = 0;
+	int i;
 #ifdef __linux__
 	char *proc;
 	char *p;
@@ -822,18 +825,6 @@ main(int argc, char **argv)
 	if (!applet)
 		eerrorx("arguments required");
 
-	if (argc > 1 && (strcmp(argv[1], "--version") == 0)) {
-		printf("%s (OpenRC", applet);
-		if ((bootlevel = rc_sys()))
-			printf(" [%s]", bootlevel);
-		printf(") " VERSION
-#ifdef BRANDING
-		    " (" BRANDING ")"
-#endif
-		    "\n");
-		exit(EXIT_SUCCESS);
-	}
-
 	/* Run our built in applets. If we ran one, we don't return. */
 	run_applets(argc, argv);
 
@@ -855,6 +846,10 @@ main(int argc, char **argv)
 		    longopts, (int *) 0)) != -1)
 	{
 		switch (opt) {
+		case 'a':
+			/* Do nothing, actual logic in run_applets, this
+			 * is a placeholder */
+			break;
 		case 'o':
 			if (*optarg == '\0')
 				optarg = NULL;
@@ -880,18 +875,18 @@ main(int argc, char **argv)
 		case 'S':
 			if (rc_conf_value("rc_sys")) {
 				bootlevel = rc_sys_v2();
-				if(bootlevel)
+				if (bootlevel)
 					printf("%s\n", bootlevel);
 			} else {
 				ewarn("WARNING: rc_sys not defined in rc.conf. Falling back to automatic detection");
 				bootlevel = rc_sys_v1();
-				if(bootlevel)
+				if (bootlevel)
 					printf("%s\n", bootlevel);
 			}
 			exit(EXIT_SUCCESS);
 			/* NOTREACHED */
-			case_RC_COMMON_GETOPT
-			    }
+		case_RC_COMMON_GETOPT
+		}
 	}
 
 	newlevel = argv[optind++];
